@@ -22,8 +22,18 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1604 2010-02-05 19:33:37Z beerli $
- 
+$Id: data.c 1685 2010-05-10 00:16:38Z beerli $
+
+-----------------------------------
+add this to the microsatellite data, this will allow to use
+a known repeat lengths to read number of sites instead of 
+number of repeats, the datafile will need an additional line
+perhaps use something like #@ 2 2 2 3  .... on the second line
+so that other non microsatellite data models 
+can ignore it
+y = Map[If[(a = Mod[#, rlen]) != 0, 
+      If[Random[] < 0.5, # - (rlen + a), # + rlen - a], #] &, x]/
+   rlen  - Min[y] + 1 
 -------------------------------------------------------*/
 /*! \file data.c
 
@@ -40,6 +50,7 @@ Data manipulation routines
 #include "migrate_mpi.h"
 #include "data.h"
 #include "sequence.h"
+#include "random.h"
 #ifdef PRETTY
 #include "pretty.h"
 #endif
@@ -278,8 +289,10 @@ get_new_data (FILE * infile, data_fmt * data, option_fmt * options, world_fmt *w
   // if we have the new haplotype input then there should be no delimiter
   // needed
   read_header (infile, data, options);
-  
   init_data_structure1 (&data, options);
+  //
+  // here I need to add the msat_lengths support
+  //
   // this will set up all the locus structure, but may need some additional
   // init_data-structure1a()
   read_sites(data, world);
@@ -441,6 +454,7 @@ void
 init_data_structure1 (data_fmt ** data, option_fmt * options)
 {
     long pop;
+    long locus;
     long numpop = (*data)->numpop;
     long loci   = (*data)->loci;
     
@@ -473,6 +487,14 @@ init_data_structure1 (data_fmt ** data, option_fmt * options)
 	(*data)->numdatatypealloc = loci;
 	(*data)->numsublocialloc = loci;
 	(*data)->subloci = (long *) mycalloc(loci,sizeof(long));
+	(*data)->numrepeatnumbers = (long *) calloc(loci, sizeof(long));
+	(*data)->repeatnumbers = (long **) calloc(loci, sizeof(long *));
+	(*data)->repeatlength = (long *) calloc(loci, sizeof(long));
+	for(locus=0;locus<loci;locus++)
+	  {
+	    (*data)->numrepeatnumbers[locus] = 1;
+	    (*data)->repeatnumbers[locus] = (long *) calloc(1, sizeof(long));
+	  }
     }
     else
     {
@@ -1180,6 +1202,36 @@ read_popdata (FILE * infile, data_fmt * data, long pop, option_fmt * options)
       }
 }
 
+long check_list(long la1, long nla1, long locus, data_fmt *data)
+{
+  if(la1 > data->numrepeatnumbers[locus])
+    {
+      data->repeatnumbers[locus] = (long *) realloc(data->repeatnumbers[locus], sizeof(long) * (la1+1));
+      memset(data->repeatnumbers[locus]+data->numrepeatnumbers[locus], 0, sizeof(long)*(la1+1-data->numrepeatnumbers[locus]));
+      data->numrepeatnumbers[locus]= la1+1;
+      data->repeatnumbers[locus][la1]=nla1;
+    }
+  else
+    {
+      if(data->repeatnumbers[locus][la1]!=0)
+	return data->repeatnumbers[locus][la1];
+    }
+  return la1;
+}
+
+void len2repeat(char *a1, long rlen, long locus, data_fmt *data)
+{
+  long la1 = (long) a1;
+  long a=0;
+  if((a=la1 % rlen) != 0)
+    {
+      long correction = (((((float) rlen) / 2.) < a) ? (-a) : (rlen/2 == a ? (UNIF_RANDUM()<0.5 ? -a : a) : (rlen - a))); 
+      long nla = check_list(la1,la1+correction, locus, data);
+      sprintf(a1,"%li",nla);
+    }
+}
+
+
 void
 read_microalleles (FILE * infile, data_fmt * data, long pop, long ind)
 {
@@ -1229,6 +1281,12 @@ read_microalleles (FILE * infile, data_fmt * data, long pop, long ind)
         {
             strcpy (a2, a1);
         }
+	if(data->repeatlength[locus]!=0)
+	  {
+	    long rlen = data->repeatlength[locus];
+	    len2repeat(a1, rlen, locus, data);
+	    len2repeat(a2, rlen, locus, data);
+          }
         strcpy (data->yy[pop][ind][locus][0], a1);
         strcpy (data->yy[pop][ind][locus][1], a2);
     }
