@@ -9,7 +9,7 @@
 #include "tools.h"
 #include "sighandler.h"
 #include "reporter.h"
-
+#include "pretty.h"
 
 extern int myID;
 
@@ -29,11 +29,11 @@ void read_from_bayesmdim_minimal_info(FILE *mdimfile, world_fmt *world,option_fm
 	{
 	  FGETS(input,LINESIZE,mdimfile);
 	  printf("%i>>>>>>> read from bayesallfile <<<<<<<<<<<<<<<<<<<<<<\n",myID);
-	  options->custm = myrealloc(options->custm, sizeof(char) * (strlen(input)+1));
+	  options->custm = (char *) myrealloc(options->custm, sizeof(char) * (strlen(input)+1));
 	  strcpy(options->custm,input+9);
 	  printf("%i> custom       = %s\n",myID, options->custm);
 	  FGETS (input, LINESIZE, mdimfile);
-	  options->custm2 = myrealloc(options->custm2, sizeof(char) * (strlen(input)+1));
+	  options->custm2 = (char *) myrealloc(options->custm2, sizeof(char) * (strlen(input)+1));
 	  strcpy(options->custm2,input+9);
 	  printf("%i> custom2      = %s\n",myID, options->custm2);
 	  FGETS (input, 1024, mdimfile);
