@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1677 2010-04-27 19:37:49Z beerli $*/
+/* $Id: main.c 1684 2010-05-08 17:48:06Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -1100,6 +1100,35 @@ get_bayeshist (world_fmt * world, option_fmt * options)
 #endif
 }
 
+void 	recalc_skyline_values(world_fmt *world, option_fmt * options, long maxreplicate)
+{
+  long i, j, locus;
+  mighistloci_fmt *aa;
+  long * eventnum;
+  const float invmax = 1./maxreplicate;
+  if(world->options->mighist && world->options->skyline)
+    {
+      for(locus=0; locus < world->loci; locus++)
+	{
+	  aa = &world->mighistloci[locus];
+	  eventnum = world->mighistloci[locus].eventbinnum;
+	  for(j=0; j< world->numpop2; j++)
+	    {
+	      for (i = 0; i < eventnum[j]; i++)
+		{
+		  aa->eventbins[j][i][0] *= invmax;
+		  aa->eventbins[j][i][1] *= invmax;
+		  aa->eventbins[j][i][2] *= invmax;
+		  aa->eventbins[j][i][3] *= invmax;
+		  aa->eventbins[j][i][4] *= invmax;
+		  aa->eventbins[j][i][5] *= invmax;
+		}
+	    }
+	}
+    }
+}
+
+
 /// get migration event time data
 /// and skyline data when present
 void
@@ -1113,7 +1142,7 @@ get_mighistdata (world_fmt * world, option_fmt * options)
     if (myID == MASTER)
     {
         if (options->mighist)
-        {
+	  {
             //get all mighist data from the workers using unpack_mighist_buffer()
             mpi_results_master (MIGMPI_MIGHIST, world, maxreplicate,
                                 unpack_mighist_buffer);
@@ -1124,12 +1153,13 @@ get_mighistdata (world_fmt * world, option_fmt * options)
 		mpi_results_master (MIGMPI_SKYLINE, world, maxreplicate,
 				    unpack_skyline_buffer);
 	      }
-        }
+	  }
 	if(/*world->options->treeprint ==BEST &&*/ world->options->treeinmemory==TRUE)
 	  {
             mpi_results_master (MIGMPI_TREESPACE, world, maxreplicate,
                                 unpack_treespace_buffer);
 	  }
+	recalc_skyline_values(world, options, maxreplicate);
     }
 #endif
     
@@ -2416,12 +2446,16 @@ MYREAL combine_scaling_factor(world_fmt *world)
 	  pop  = bayes->map[i][1];
 	}
       scaling_factor += exp(bayes->scaling_factors[pop] - bayes->maxmaxvala);
-      //printf("%f\n",scaling_factor);
+#ifdef DEBUG
+      printf("%li  %li %g %g\n",i, pop, scaling_factor, bayes->maxmaxvala);
+#endif
     }
   scaling_factor = log(scaling_factor) + bayes->maxmaxvala;
   if(world->options->has_bayesfile)
     {
+#ifdef DEBUG
       printf("# Scaling factor %20.20f\n",scaling_factor);
+#endif
       fprintf(world->bayesfile, "# Scaling factor %20.20f\n",scaling_factor);
     }
   return scaling_factor;
@@ -2430,7 +2464,7 @@ MYREAL combine_scaling_factor(world_fmt *world)
 void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 {
 #ifdef MPI
-  static boolean done=FALSE;
+  //static boolean done=FALSE;
 #endif
   long t;
   const long hc = EARTH->options->heated_chains;
@@ -2572,7 +2606,7 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 	  bfsum2 += scaling_factor;
 	  hsum   += scaling_factor;
 	  fprintf(file,"---------------------------------------------------------------------------------------\n");
-	  fprintf(file,"  All  %22.2f        %22.2f           %12.2f\n", bfsum, bfsum2, hsum); 
+	  fprintf(file,"  All  %22.2f        %22.2f           %12.2f\n[Scaling factor = %f]\n", bfsum, bfsum2, hsum, scaling_factor); 
 #ifdef PRETTY
 	  if(file==EARTH->outfile)
 	    pdf_bayes_factor_rawscores(-1, bfsum, bfsum2, hsum);
@@ -2621,7 +2655,7 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
     }
 #ifdef PRETTY
   if(file==EARTH->outfile)
-    pdf_bayes_factor(EARTH, bfsum, bfsum2, hsum, asum, maxreplicate);
+    pdf_bayes_factor(EARTH, bfsum, bfsum2, hsum, asum, maxreplicate,scaling_factor);
 #endif
 }
 
