@@ -18,7 +18,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c 1589 2009-11-19 22:14:25Z beerli $
+$Id: mcmc1.c 1665 2010-03-21 20:28:10Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc1.c
 
@@ -748,12 +748,14 @@ chooseOrigin (proposal_fmt * proposal)
 {
     long elem = 0, oldelem = (proposal->sumtips * 2.);
     node *tmp=NULL, **goal;
-    goal = (node **) mycalloc (oldelem, sizeof (node *));
+    //032110 goal = (node **) mycalloc (oldelem, sizeof (node *));
     //#ifdef DEBUG
     //traverse_check(crawlback (proposal->root->next));
     //#endif
-    traverseAllNodes (crawlback (proposal->root->next), &goal, &elem, &oldelem,
-                      NO_MIGR_NODES);
+    //032110 traverseAllNodes (crawlback (proposal->root->next), &goal, &elem, &oldelem,
+    //032110                  NO_MIGR_NODES);
+    goal = proposal->world->nodep;
+    elem = proposal->world->sumtips * 2;
     switch(elem)
       {
       case 0:
@@ -765,9 +767,11 @@ chooseOrigin (proposal_fmt * proposal)
 	break;
       default:
 	tmp = goal[RANDINT (0, elem - 2)];
+	while(tmp->back->type =='r')
+	  tmp = goal[RANDINT (0, elem - 2)];
 	break;
       }
-    myfree(goal);
+    //032110 myfree(goal);
     proposal->origin = tmp;
     if (proposal->origin != showtop (crawlback (proposal->root->next)))
     {
