@@ -16,7 +16,7 @@
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 1593 2009-12-06 22:42:27Z beerli $
+  $Id: migration.h 1683 2010-05-06 04:05:30Z beerli $
   *----------------------------------------------------------------
 */
 /**
@@ -275,6 +275,9 @@ typedef struct _data
   long numdatatypealloc;
   long numsublocialloc;
   long numlocitypesalloc;
+  long *numrepeatnumbers;
+  long **repeatnumbers;
+  long *repeatlength;
 }
 data_fmt;
 
