@@ -6,7 +6,7 @@
  P R O F I L E    L I K E L I H O O D    R O U T I N E S 
  
  Peter Beerli 1997, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
@@ -16,7 +16,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: profile.c 886 2007-08-18 03:09:50Z beerli $
+$Id: profile.c 1644 2010-02-06 17:33:49Z beerli $
  
 -------------------------------------------------------*/
 /*! \file profile.c
@@ -916,7 +916,7 @@ prognose_profile_end (time_t starttime, long numpop2, long nn)
 
         nowstruct = localtime (&nowbin);
 
-        strftime (nowstr, LINESIZE, "%R %B %e %Y", nowstruct);
+        strftime (nowstr, LINESIZE, "%H:%M %B %d %Y", nowstruct);
         FPRINTF (stdout, "           Prognosed end of run: %s\n", nowstr);
     }
     else
