@@ -16,7 +16,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 1565 2009-08-03 14:48:56Z beerli $
+$Id: reporter.c 1622 2010-02-05 20:58:37Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -477,11 +477,11 @@ MYREAL single_chain_var(world_fmt *world, long T, MYREAL *variance, MYREAL *auto
   if(!done)
     {
       nn = world->numpop2 + world->bayes->mu * world->loci + 1;
-      mean = mycalloc(nn,sizeof(double));
-      S    = mycalloc(nn,sizeof(double));
-      r    = mycalloc(nn,sizeof(double));
-      xold = mycalloc(nn,sizeof(double));
-      xstart = mycalloc(nn,sizeof(double));
+      mean = (double *) mycalloc(nn,sizeof(double));
+      S    = (double *) mycalloc(nn,sizeof(double));
+      r    = (double *) mycalloc(nn,sizeof(double));
+      xold = (double *) mycalloc(nn,sizeof(double));
+      xstart = (double *) mycalloc(nn,sizeof(double));
       done=TRUE;
     }
   // reset static variable for each chain
@@ -499,7 +499,7 @@ MYREAL single_chain_var(world_fmt *world, long T, MYREAL *variance, MYREAL *auto
   if(T==0)
     return 0;
 
-  delta = mycalloc(nn,sizeof(double));
+  delta = (double *) mycalloc(nn,sizeof(double));
   //handles BAYES or ML
  start = (world->options->bayes_infer ? 0 : world->numpop2);
   if(n==0) //initialization of mean calculator
@@ -618,19 +618,19 @@ void calculate_ess_frombayes(world_fmt *world, long T, MYREAL *params, long locu
     {
       nnbase = (world->numpop2 + world->bayes->mu * world->loci + 1);
       nn = world->loci * nnbase;
-      n = mycalloc(world->loci,sizeof(long));
-      mean = mycalloc(nn,sizeof(double));
-      S    = mycalloc(nn,sizeof(double));
-      r    = mycalloc(nn,sizeof(double));
-      xold = mycalloc(nn,sizeof(double));
-      xstart = mycalloc(nn,sizeof(double));
+      n = (long *) mycalloc(world->loci,sizeof(long));
+      mean = (double *) mycalloc(nn,sizeof(double));
+      S    = (double *) mycalloc(nn,sizeof(double));
+      r    = (double *) mycalloc(nn,sizeof(double));
+      xold = (double *) mycalloc(nn,sizeof(double));
+      xstart = (double *) mycalloc(nn,sizeof(double));
       done=TRUE;
     }
   // syntax so that an init really works
   if(T==0)
     return;
 
-  delta = mycalloc(nnbase,sizeof(double));
+  delta = (double *) mycalloc(nnbase,sizeof(double));
   //handles BAYES or ML
  start = (world->options->bayes_infer ? 0 : world->numpop2);
   if(n[locus]==0) //initialization of mean calculator
