@@ -289,7 +289,7 @@ void calculate_expected_values(tetra **eventbins,
   if(bin >= eventbinnum[pop])
     {
       allocsize      = bin+10;
-      eventbins[pop] = myrealloc(eventbins[pop], allocsize * sizeof(tetra));
+      eventbins[pop] = (tetra *) myrealloc(eventbins[pop], allocsize * sizeof(tetra));
       for(i=eventbinnum[pop];i < allocsize; i++)
 	{
 	  for(j=0;j<9;j++)
@@ -480,7 +480,7 @@ void read_expected_values_fromfile(FILE *file, world_fmt *world)
 	  if(allocsize[spacer + pop] < eventbinnum[pop])
 	    {
 	      allocsize[spacer + pop] += SOME_ELEMENTS;
-	      eventbins[pop] = myrealloc(eventbins[pop], allocsize[spacer + pop] * sizeof(tetra));
+	      eventbins[pop] = (tetra *) myrealloc(eventbins[pop], allocsize[spacer + pop] * sizeof(tetra));
 	    }
 
 	  if(i==0)
