@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1624 2010-02-05 21:02:19Z beerli $
+$Id: tools.c 1683 2010-05-06 04:05:30Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -93,9 +93,11 @@ void doublevec2d (MYREAL ***v, long size1, long size2);
 void floatvec2d (float ***v, long size1, long size2);
 void charvec1d (char **v, long size1);
 void charvec2d (char ***v, long size1, long size2);
+void intvec2d (long ***v, long size1, long size2);
 void free_doublevec2d (MYREAL **v);
 void free_floatvec2d (float **v);
 void free_charvec2d (char **v);
+void free_intvec2d (long **v);
 void setdoublevec1d (MYREAL **v, MYREAL *w, long size);
 void add_vector (MYREAL *result, MYREAL *v, long size);
 
@@ -202,6 +204,20 @@ charvec2d (char ***v, long size1, long size2)
         (*v)[i] = (*v)[0] + size2 * i;
     }
 }
+///
+/// allocates columns and rows for a matrix of strings
+/// use free_intvec2d() to free this.
+void
+intvec2d (long ***v, long size1, long size2)
+{
+    long i;
+    *v = (long **) mycalloc (size1, sizeof (long *));
+    (*v)[0] = (long *) mycalloc (size1 * size2, sizeof (long));
+    for (i = 1; i < size1; i++)
+    {
+        (*v)[i] = (*v)[0] + size2 * i;
+    }
+}
 
 /// free 2D vector of MYREAL
 void
@@ -218,12 +234,19 @@ free_floatvec2d (float **v)
     myfree(v[0]);
     myfree(v);
 }
+
 void
 free_charvec2d (char **v)
 {
     myfree(v[0]);
     myfree(v);
 }
+void
+free_intvec2d (long **v)
+{
+    myfree(v[0]);
+    myfree(v);
+}
 
 void
 setdoublevec1d (MYREAL **v, MYREAL *w, long size)
